<?php
/**
 * Stripe add-on for Events Manager Pro 
 *
 * An addon for the Events Manager Pro plugin that provides a gateway for Stripe
 *
 * @package   Events_Manager_Stripe
 * @author    Sam De Francesco <sam@defrances.co>
 * @license   GPL-2.0+
 * @link      http://wordpress.org/plugins/events-manager-pro-stripe-gateway/
 * @copyright 2013 Sam De Francesco
 *
 * @wordpress-plugin
 * Plugin Name: Events Manager Pro Stripe Gateway
 * Plugin URI:  http://wordpress.org/plugins/events-manager-pro-stripe-gateway/
 * Description: A Stripe Gateway add-on for the Event Manager Pro plugin
 * Version:     1.0.5
 * Author:      Sam De Francesco <sam@defrances.co>
 * Author URI:  http://defrances.co/
 * Text Domain: events-manager-stripe-locale
 * Donate link: https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=B3HQNRHL23FQW
 * License:     GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Domain Path: /lang
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * events manager pro is a pre-requisite
 */
function emp_stripe_prereq() {
    ?> <div class="error"><p><?php _e('Please ensure you have <a href="http://eventsmanagerpro.com/">Events Manager Pro</a>
                                       installed, as this is a requirement for the Stripe add-on.','events-manager-stripe'); ?></p>
       </div>
    <?php
}

/**
 * initialise plugin once other plugins are loaded 
 */
function emp_stripe_register() {
    //check that EM Pro is installed
    if( ! defined( 'EMP_VERSION' ) ) {
        add_action( 'admin_notices', 'emp_stripe_requirements' );
        return false; //don't load plugin further
    }

    require_once( plugin_dir_path( __FILE__ ) . 'class-events-manager-stripe.php' );
    EM_Gateways::register_gateway('stripe', 'EM_Gateway_Stripe');

}

add_action( 'plugins_loaded', 'emp_stripe_register', 1000);

/**
 * Set meta links in the plugins page 
 */
function emp_stripe_metalinks( $actions, $file, $plugin_data ) {
    $new_actions = array();
    $new_actions[] = sprintf( '<a href="'.EM_ADMIN_URL.'&amp;page=events-manager-gateways&amp;action=edit&amp;gateway=stripe">%s</a>', __('Settings', 'dbem') );
    $new_actions[] = sprintf( '<a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&amp;hosted_button_id=B3HQNRHL23FQW">%s</a>', __('Donate', 'dbem') );
    $new_actions = array_merge( $new_actions, $actions );
    return $new_actions;
}

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'emp_stripe_metalinks', 10, 3 );

/* eof */
